# Notifications
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/notifications#overview)
  * [Notification Channels](https://help.sap.com/docs/leanix/ea/notifications#notification-channels)
  * [Setting Your Notification Preferences](https://help.sap.com/docs/leanix/ea/notifications#setting-your-notification-preferences)


Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.
